/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: cfgmoduleqbm.h 347 2006-01-09 22:40:04Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef QBM_CFGMODULEQBM_H
#define QBM_CFGMODULEQBM_H

#include <qbanking/qbcfgmodule.h>

class KBanking;


class CfgModuleQbm : public QBCfgModule {
private:
  KBanking *_banking;

public:
  CfgModuleQbm(KBanking *kb);
  virtual ~CfgModuleQbm();

  virtual QBCfgTabPageAccount *getEditAccountPage(AB_ACCOUNT *a,
                                                  QWidget *parent=0);

};



#endif // QBM_CFGMODULEQBM_H
